You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by bo...@apache.org on 2014/01/22 20:38:46 UTC

[35/50] [abbrv] git commit: Spelling fixes

Spelling fixes


Project: http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/commit/dbea6320
Tree: http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/tree/dbea6320
Diff: http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/diff/dbea6320

Branch: refs/heads/master
Commit: dbea6320c5b62bce42e23f46fb0271daed9ce867
Parents: f25327b
Author: Josh Soref <js...@blackberry.com>
Authored: Wed Oct 30 21:06:58 2013 -0400
Committer: Joe Bowser <bo...@apache.org>
Committed: Wed Jan 22 11:37:21 2014 -0800

----------------------------------------------------------------------
 RELEASENOTES.md                                      | 2 +-
 bin/templates/cordova/lib/build.js                   | 2 +-
 bin/templates/cordova/lib/emulator.js                | 6 +++---
 bin/templates/cordova/lib/log.js                     | 2 +-
 bin/templates/cordova/lib/run.js                     | 4 ++--
 bin/templates/project/assets/www/js/index.js         | 2 +-
 framework/src/org/apache/cordova/App.java            | 4 ++--
 framework/src/org/apache/cordova/CordovaWebView.java | 6 +++---
 8 files changed, 14 insertions(+), 14 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/blob/dbea6320/RELEASENOTES.md
----------------------------------------------------------------------
diff --git a/RELEASENOTES.md b/RELEASENOTES.md
index 915d563..a3e4815 100644
--- a/RELEASENOTES.md
+++ b/RELEASENOTES.md
@@ -32,7 +32,7 @@
 * [CB-4764] Deprecated DirectoryManager.java (moved into plugins)
 * [CB-4763] Deprecated FileHelper.java (moved into plugins), Move getMimeType() into CordovaResourceApi.
 * [CB-4725] Add CordovaWebView.CORDOVA_VERSION constant
-* Incremeting version check for Android 4.3 API Level 18
+* Incrementing version check for Android 4.3 API Level 18
 * [CB-3542] rewrote cli tooling scripts in node
 * Allow CordovaChromeClient subclasses access to CordovaInterface and CordovaWebView members
 * Refactor CordovaActivity.init so that subclasses can easily override factory methods for webview objects

http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/blob/dbea6320/bin/templates/cordova/lib/build.js
----------------------------------------------------------------------
diff --git a/bin/templates/cordova/lib/build.js b/bin/templates/cordova/lib/build.js
index e57e26b..f0adb37 100644
--- a/bin/templates/cordova/lib/build.js
+++ b/bin/templates/cordova/lib/build.js
@@ -78,7 +78,7 @@ module.exports.get_apk = function() {
 }
 
 module.exports.help = function() {
-    console.log('Usage: ' + path.relative(process.cwd(), path.join(ROOT, 'corodva', 'build')) + ' [build_type]');
+    console.log('Usage: ' + path.relative(process.cwd(), path.join(ROOT, 'cordova', 'build')) + ' [build_type]');
     console.log('Build Types : ');
     console.log('    \'--debug\': Default build, will build project in using ant debug');
     console.log('    \'--release\': will build project using ant release');

http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/blob/dbea6320/bin/templates/cordova/lib/emulator.js
----------------------------------------------------------------------
diff --git a/bin/templates/cordova/lib/log.js b/bin/templates/cordova/lib/log.js
index 7339b1c..329dfc9 100644
--- a/bin/templates/cordova/lib/log.js
+++ b/bin/templates/cordova/lib/log.js
@@ -51,7 +51,7 @@ module.exports.run = function() {
 }
 
 module.exports.help = function() {
-    console.log('Usage: ' + path.relative(process.cwd(), path.join(ROOT, 'corodva', 'log')));
+    console.log('Usage: ' + path.relative(process.cwd(), path.join(ROOT, 'cordova', 'log')));
     console.log('Gives the logcat output on the command line.');
     process.exit(0);
 }

http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/blob/dbea6320/bin/templates/cordova/lib/run.js
----------------------------------------------------------------------
diff --git a/bin/templates/cordova/lib/run.js b/bin/templates/cordova/lib/run.js
index 6806014..dd67901 100644
--- a/bin/templates/cordova/lib/run.js
+++ b/bin/templates/cordova/lib/run.js
@@ -26,7 +26,7 @@ var path  = require('path'),
     Q = require('q');
 
 /*
- * Runs the application on a device if availible.
+ * Runs the application on a device if available.
  * If not device is found, it will use a started emulator.
  * If no started emulators are found it will attempt to start an avd.
  * If no avds are found it will error out.
@@ -91,7 +91,7 @@ var path  = require('path'),
                 }
             });
         } else {
-            // no target given, deploy to device if availible, otherwise use the emulator.
+            // no target given, deploy to device if available, otherwise use the emulator.
             return device.list()
             .then(function(device_list) {
                 if (device_list.length > 0) {

http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/blob/dbea6320/bin/templates/project/assets/www/js/index.js
----------------------------------------------------------------------
diff --git a/bin/templates/project/assets/www/js/index.js b/bin/templates/project/assets/www/js/index.js
index 31d9064..87b5660 100644
--- a/bin/templates/project/assets/www/js/index.js
+++ b/bin/templates/project/assets/www/js/index.js
@@ -31,7 +31,7 @@ var app = {
     // deviceready Event Handler
     //
     // The scope of 'this' is the event. In order to call the 'receivedEvent'
-    // function, we must explicity call 'app.receivedEvent(...);'
+    // function, we must explicitly call 'app.receivedEvent(...);'
     onDeviceReady: function() {
         app.receivedEvent('deviceready');
     },

http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/blob/dbea6320/framework/src/org/apache/cordova/App.java
----------------------------------------------------------------------
diff --git a/framework/src/org/apache/cordova/App.java b/framework/src/org/apache/cordova/App.java
index 86c6572..64af74e 100755
--- a/framework/src/org/apache/cordova/App.java
+++ b/framework/src/org/apache/cordova/App.java
@@ -190,7 +190,7 @@ public class App extends CordovaPlugin {
      * @param override		T=override, F=cancel override
      */
     public void overrideBackbutton(boolean override) {
-        LOG.i("App", "WARNING: Back Button Default Behaviour will be overridden.  The backbutton event will be fired!");
+        LOG.i("App", "WARNING: Back Button Default Behavior will be overridden.  The backbutton event will be fired!");
         webView.bindButton(override);
     }
 
@@ -202,7 +202,7 @@ public class App extends CordovaPlugin {
      * @param override      T=override, F=cancel override
      */
     public void overrideButton(String button, boolean override) {
-        LOG.i("App", "WARNING: Volume Button Default Behaviour will be overridden.  The volume event will be fired!");
+        LOG.i("App", "WARNING: Volume Button Default Behavior will be overridden.  The volume event will be fired!");
         webView.bindButton(button, override);
     }
 

http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/blob/dbea6320/framework/src/org/apache/cordova/CordovaWebView.java
----------------------------------------------------------------------
diff --git a/framework/src/org/apache/cordova/CordovaWebView.java b/framework/src/org/apache/cordova/CordovaWebView.java
index 767ea00..36ef8a1 100755
--- a/framework/src/org/apache/cordova/CordovaWebView.java
+++ b/framework/src/org/apache/cordova/CordovaWebView.java
@@ -866,11 +866,11 @@ public class CordovaWebView extends AmazonWebView {
                     if (this.backHistory()) {
                         return true;
                     }
-                    // If not, then invoke default behaviour
+                    // If not, then invoke default behavior
                     else {
                         //this.activityState = ACTIVITY_EXITING;
                     	//return false;
-                    	// If they hit back button when app is initializing, app should exit instead of hang until initilazation (CB2-458)
+                    	// If they hit back button when app is initializing, app should exit instead of hang until initialization (CB2-458)
                     	this.cordova.getActivity().finish();
                     }
                 }
@@ -1072,7 +1072,7 @@ public class CordovaWebView extends AmazonWebView {
 
     public void hideCustomView() {
         // This code is adapted from the original Android Browser code, licensed under the Apache License, Version 2.0
-        Log.d(TAG, "Hidding Custom View");
+        Log.d(TAG, "Hiding Custom View");
         if (mCustomView == null) return;
 
         // Hide the custom view.
diff --git a/bin/templates/cordova/lib/emulator.js b/bin/templates/cordova/lib/emulator.js
index fe24480..a8663fa 100644
--- a/bin/templates/cordova/lib/emulator.js
+++ b/bin/templates/cordova/lib/emulator.js
@@ -143,8 +143,8 @@ module.exports.list_targets = function() {
 /*
  * Starts an emulator with the given ID,
  * and returns the started ID of that emulator.
  * If no ID is given it will used the first image availible,
  * if no image is availible it will error out (maybe create one?).
  *
  * Returns a promise.
  */
@@ -274,7 +274,7 @@ module.exports.create_image = function(name, target) {
         .then(function() {
             // TODO: This seems like another error case, even though it always happens.
             console.error('ERROR : Unable to create an avd emulator, no targets found.');
-            console.error('Please insure you have targets availible by runing the "android" command');
+            console.error('Please insure you have targets available by running the "android" command');
             return Q.reject();
         }, function(error) {
             console.error('ERROR : Failed to create emulator image : ');

http://git-wip-us.apache.org/repos/asf/cordova-amazon-fireos/blob/dbea6320/bin/templates/cordova/lib/log.js
----------------------------------------------------------------------
@@ -143,8 +143,8 @@ module.exports.list_targets = function() {
  * Starts an emulator with the given ID,
  * and returns the started ID of that emulator.
- * If no ID is given it will used the first image availible,
- * if no image is availible it will error out (maybe create one?).
+ * If no ID is given it will used the first image available,
+ * if no image is available it will error out (maybe create one?).
  *
  * Returns a promise.